Index: /issm/trunk-jpl/startup.m
===================================================================
--- /issm/trunk-jpl/startup.m	(revision 12157)
+++ /issm/trunk-jpl/startup.m	(revision 12158)
@@ -11,35 +11,35 @@
 lastwarn(''); 
 
 %Recover ISSM_TIER , or if on a Windows machine, ISSM_TIER_WIN
 if ~ispc,
-	ISSM_TIER=getenv('ISSM_TIER');
+	ISSM_DIR=getenv('ISSM_DIR');
 else
-	ISSM_TIER=getenv('ISSM_TIER_WIN');
-	%ISSM_TIER='';
+	ISSM_DIR=getenv('ISSM_DIR_WIN');
+	%ISSM_DIR='';
 end
-if (isempty(ISSM_TIER)),
-	error('''ISSM_TIER'' environment variable is empty! You should define ISSM_TIER in your .cshrc or .bashrc!');
+if (isempty(ISSM_DIR)),
+	error('''ISSM_DIR'' environment variable is empty! You should define ISSM_DIR in your .cshrc or .bashrc!');
 end
 
 %Now add all issm code paths necessary to run issm smoothly. 
 %We capture the error output, so that we can warn the user to update 
 %the variable ISSM_TIER in this file, in case it is not correctly setup. 
 
 %ISSM path
-addpath([ISSM_TIER '/src/m/utils/']); %loads recursivepath
-addpath([ISSM_TIER '/bin']);
-addpath(recursivepath([ISSM_TIER '/src/m']));
-addpath(recursivepath([ISSM_TIER '/externalpackages/scotch']));
-addpath(recursivepath([ISSM_TIER '/externalpackages/canos']));
-addpath(recursivepath([ISSM_TIER '/externalpackages/kml']));
-addpath(recursivepath([ISSM_TIER '/externalpackages/export_fig']));
-addpath(recursivepath([ISSM_TIER '/externalpackages/googleearthtoolbox']));
-addpath(recursivepath([ISSM_TIER '/externalpackages/cm_and_cb_utilities']));
+addpath([ISSM_DIR '/src/m/utils/']); %loads recursivepath
+addpath([ISSM_DIR '/bin']);
+addpath(recursivepath([ISSM_DIR '/src/m']));
+addpath(recursivepath([ISSM_DIR '/externalpackages/scotch']));
+addpath(recursivepath([ISSM_DIR '/externalpackages/canos']));
+addpath(recursivepath([ISSM_DIR '/externalpackages/kml']));
+addpath(recursivepath([ISSM_DIR '/externalpackages/export_fig']));
+addpath(recursivepath([ISSM_DIR '/externalpackages/googleearthtoolbox']));
+addpath(recursivepath([ISSM_DIR '/externalpackages/cm_and_cb_utilities']));
 
-clear ISSM_TIER;
+clear ISSM_DIR;
 
 %Check on any warning messages that might indicate that the paths were not correct. 
 if ~isempty(lastwarn),
-	fprintf('\n  Error trying to setup ''ISSM'' code paths. Try and update the ISSM_TIER variable in your .cshrc or .bashrc!\n');
+	fprintf('\n  Error trying to setup ''ISSM'' code paths. Try and update the ISSM_DIR variable in your .cshrc or .bashrc!\n');
 	fprintf('  ''ISSM'' will not  work at all until this is resolved\n\n');
 else
@@ -11,35 +11,35 @@
 lastwarn(''); 
 
-%Recover ISSM_TIER , or if on a Windows machine, ISSM_TIER_WIN
+%Recover ISSM_DIR , or if on a Windows machine, ISSM_DIR_WIN
 if ~ispc,
@@ -11,35 +11,35 @@
 %Now add all issm code paths necessary to run issm smoothly. 
 %We capture the error output, so that we can warn the user to update 
-%the variable ISSM_TIER in this file, in case it is not correctly setup. 
+%the variable ISSM_DIR in this file, in case it is not correctly setup. 
 
 %ISSM path
Index: /issm/trunk-jpl/startup.py
===================================================================
--- /issm/trunk-jpl/startup.py	(revision 12157)
+++ /issm/trunk-jpl/startup.py	(revision 12158)
@@ -5,21 +5,21 @@
 #  before handing over the prompt to the user if the environment variable
 #  PYTHONSTARTUP is defined:
-#  export PYTHONSTARTUP=$ISSM_TIER/startup.py
+#  export PYTHONSTARTUP=$ISSM_DIR/startup.py
 #  This startup script should be run by users before trying to use ISSM.
 
 import os,sys
 
-#Recover ISSM_TIER, ISSM_DIR  and USERNAME
-ISSM_TIER=os.getenv('ISSM_TIER')
+#Recover ISSM_DIR and USERNAME
+ISSM_DIR=os.getenv('ISSM_DIR')
 USERNAME =os.getenv('USER')
-if(ISSM_TIER==None):
-	raise NameError('"ISSM_TIER" environment variable is empty! You should define ISSM_TIER in your .cshrc or .bashrc!')
+if(ISSM_DIR==None):
+	raise NameError('"ISSM_DIR" environment variable is empty! You should define ISSM_DIR in your .cshrc or .bashrc!')
 
 #Now add all issm code paths necessary to run issm smoothly. 
 #We capture the error output, so that we can warn the user to update 
 #the variable ISSM_TIER in this file, in case it is not correctly setup. 
 
 #ISSM path. Go through src/py and load everything we find  that looks like a python file
-for root,dirs,files in os.walk(ISSM_TIER+ '/src/py'):
+for root,dirs,files in os.walk(ISSM_DIR+ '/src/py'):
 	for file in files:
 		if file.find(".py") != -1:
@@ -30,5 +30,5 @@
 				#__import__(file)
 
-for root,dirs,files in os.walk(ISSM_TIER+ '/src/m'):
+for root,dirs,files in os.walk(ISSM_DIR+ '/src/m'):
 	for file in files:
 		if file.find(".py") != -1:
@@ -39,5 +39,5 @@
 				#__import__(file)
 				
-sys.path.append(ISSM_TIER + '/src/modules/python')
+sys.path.append(ISSM_DIR + '/src/modules/python')
 
 #Deal with scipy import: 
@@ -5,21 +5,21 @@
 #Now add all issm code paths necessary to run issm smoothly. 
 #We capture the error output, so that we can warn the user to update 
-#the variable ISSM_TIER in this file, in case it is not correctly setup. 
+#the variable ISSM_DIR in this file, in case it is not correctly setup. 
 
 #ISSM path. Go through src/py and load everything we find  that looks like a python file
